@@ -202,10 +202,16 @@ setMethod("q.r", "DiscreteDistribution", function(object){
 
 setMethod("+", c("DiscreteDistribution","DiscreteDistribution"),
 function(e1,e2){
-            e1 <- as(e1, "LatticeDistribution")
-            e2 <- as(e2, "LatticeDistribution")
-            if(is(e1, "LatticeDistribution") & is(e2, "LatticeDistribution"))
-                return(e1 + e2)
+            e1.L <- as(e1, "LatticeDistribution")
+            e2.L <- as(e2, "LatticeDistribution")
+            if(is(e1.L, "LatticeDistribution") & is(e2.L, "LatticeDistribution"))
+                {w1 <- width(lattice(e1.L))
+                 w2 <- width(lattice(e2.L))
+                 W <- sort(abs(c(w1,w2)))
+                 if (abs(abs(w1)-abs(w2))<getdistrOption("DistrResolution") ||
+                     W[2] %% W[1] < getdistrOption("DistrResolution") )
+                     return(e1.L + e2.L)
+                } 
             convolutedsupport <- rep(support(e1), each = length(support(e2))) +
                                  support(e2)
 
@@ -414,3 +420,17 @@ setMethod("sqrt", "DiscreteDistribution",
 
 }          
 
+setMethod("prob", "DiscreteDistribution", 
+function(object) {sp <- object@support
+                  pr <- object@d(sp)
+                  names(pr) <- paste(sp)
+                  return(pr)
+                  })
+## Replace Methods
+setReplaceMethod("prob", "DiscreteDistribution", 
+                  function(object, value){ 
+                  sp <- object@support
+                  .withArith <- object@.withArith
+                  .withSim <- object@.withSim
+                  DiscreteDistribution(supp=sp, prob=value,
+                            .withArith=.withArith,.withSim=.withSim)})
